@@ -2,13 +2,15 @@
 
 import logging
 import os
-import yaml
 from pathlib import Path
 from typing import Any
+
+import yaml
 from fastapi import FastAPI
 from fastapi.middleware.cors import CORSMiddleware
 
-from .routers import conbus
+from xp.api.routers import conbus
+from xp.utils.dependencies import ServiceContainer
 
 # Set up logging
 logging.basicConfig(level=logging.INFO)
@@ -56,8 +58,12 @@ def load_api_config() -> dict[str, Any]:
     return config
 
 
-def create_app() -> FastAPI:
-    """Create and configure the FastAPI application."""
+def create_app(container: ServiceContainer) -> FastAPI:
+    """Create and configure the FastAPI application.
+
+    Args:
+        container: Optional ServiceContainer instance. If not provided, a new one will be created.
+    """
     config = load_api_config()
 
     fastapi = FastAPI(
@@ -77,6 +83,9 @@ def create_app() -> FastAPI:
         allow_headers=config["cors_headers"],
     )
 
+    # Initialize service container
+    fastapi.state.container = container
+
     # Include routers
     fastapi.include_router(conbus.router)
 
@@ -99,21 +108,3 @@ def create_app() -> FastAPI:
 
     logger.info(f"FastAPI application created: {config['title']} v{config['version']}")
     return fastapi
-
-
-# Create the application instance
-app = create_app()
-
-
-if __name__ == "__main__":
-    import uvicorn
-
-    # Development server configuration
-    host = os.getenv("API_HOST", "127.0.0.1")
-    port = int(os.getenv("API_PORT", "8000"))
-    reload = os.getenv("API_RELOAD", "true").lower() == "true"
-
-    logger.info(f"Starting development server on {host}:{port}")
-    uvicorn.run(
-        "xp.api.main:app", host=host, port=port, reload=reload, log_level="info"
-    )
