@@ -3,12 +3,13 @@
 import logging
 from typing import Union
 
+from fastapi import Request
 from fastapi.responses import JSONResponse
 
-from .conbus import router
-from .errors import handle_service_error
-from ..models.api import ApiResponse, ApiErrorResponse
-from ...services.conbus_custom_service import ConbusCustomService
+from xp.api.models.api import ApiErrorResponse, ApiResponse
+from xp.api.routers.conbus import router
+from xp.api.routers.errors import handle_service_error
+from xp.services.conbus.conbus_custom_service import ConbusCustomService
 
 logger = logging.getLogger(__name__)
 
@@ -24,14 +25,17 @@ logger = logging.getLogger(__name__)
     },
 )
 async def custom_function(
-    serial_number: str = "1702033007", function_code: str = "02", data: str = "00"
+    request: Request,
+    serial_number: str = "1702033007",
+    function_code: str = "02",
+    data: str = "00",
 ) -> Union[ApiResponse, ApiErrorResponse, JSONResponse]:
     """
     Initiate a Datapoint operation to find devices on the network.
 
     Sends a broadcastDatapoint telegram and collects responses from all connected devices.
     """
-    service = ConbusCustomService()
+    service = request.app.state.container.get_container().resolve(ConbusCustomService)
     # SendDatapoint telegram and receive responses
     with service:
         response = service.send_custom_telegram(serial_number, function_code, data)
