@@ -5,7 +5,8 @@ import sys
 import click
 import uvicorn
 
-from .api import api
+from xp.api.main import create_app
+from xp.cli.commands.api import api
 
 
 @api.command("start")
@@ -47,8 +48,15 @@ from .api import api
     default=True,
     help="Enable/disable access log (default: enabled)",
 )
+@click.pass_context
 def start_api_server(
-    host: str, port: int, reload: bool, workers: int, log_level: str, access_log: bool
+    context: click.Context,
+    host: str,
+    port: int,
+    reload: bool,
+    workers: int,
+    log_level: str,
+    access_log: bool,
 ) -> None:
     """
     Start the FastAPI server.
@@ -93,9 +101,14 @@ def start_api_server(
     if reload:
         click.echo(click.style("Development mode: Auto-reload enabled", fg="green"))
 
+    # Get container from CLI context or create new one
+    container = context.obj.get("container")
+
     try:
+        # For production mode, create app instance with container
+        app = create_app(container)
         uvicorn.run(
-            "xp.api.main:app",
+            app,
             host=host,
             port=port,
             reload=reload,
