@@ -1,15 +1,17 @@
 """File operations CLI commands for console bus logs."""
 
-import click
 import json
+
+import click
+from click import Context
 from click_help_colors import HelpColorsGroup
 
-from ..utils.decorators import (
+from xp.cli.utils.decorators import (
     file_operation_command,
     handle_service_errors,
 )
-from ..utils.formatters import StatisticsFormatter, OutputFormatter
-from ..utils.error_handlers import CLIErrorHandler
+from xp.cli.utils.error_handlers import CLIErrorHandler
+from xp.cli.utils.formatters import OutputFormatter, StatisticsFormatter
 
 
 @click.group(
@@ -25,9 +27,11 @@ def file() -> None:
 @file.command("decode")
 @click.argument("log_file_path")
 @click.option("--summary", is_flag=True, help="Show summary statistics only")
+@click.pass_context
 @file_operation_command()
 @handle_service_errors(Exception)
 def decode_log_file(
+    ctx: Context,
     log_file_path: str,
     filter_type: str,
     filter_direction: str,
@@ -42,10 +46,10 @@ def decode_log_file(
     \b
         xp file decode conbus.log
     """
-    from ...services.log_file_service import LogFileService
-    from ...utils.time_utils import parse_time_range, TimeParsingError
+    from xp.services.log_file_service import LogFileService
+    from xp.utils.time_utils import TimeParsingError, parse_time_range
 
-    service = LogFileService()
+    service = ctx.obj.get("container").get_container().resolve(LogFileService)
     StatisticsFormatter(True)
 
     try:
@@ -98,8 +102,9 @@ def decode_log_file(
 
 @file.command("analyze")
 @click.argument("log_file_path")
+@click.pass_context
 @handle_service_errors(Exception)
-def analyze_log_file(log_file_path: str) -> None:
+def analyze_log_file(ctx: Context, log_file_path: str) -> None:
     """
     Analyze console bus log file for patterns and statistics.
 
@@ -108,9 +113,9 @@ def analyze_log_file(log_file_path: str) -> None:
     \b
         xp file analyze conbus.log
     """
-    from ...services.log_file_service import LogFileService
+    from xp.services.log_file_service import LogFileService
 
-    service = LogFileService()
+    service = ctx.obj.get("container").get_container().resolve(LogFileService)
     StatisticsFormatter(True)
 
     try:
@@ -127,8 +132,9 @@ def analyze_log_file(log_file_path: str) -> None:
 
 @file.command("validate")
 @click.argument("log_file_path")
+@click.pass_context
 @handle_service_errors(Exception)
-def validate_log_file(log_file_path: str) -> None:
+def validate_log_file(ctx: Context, log_file_path: str) -> None:
     """
     Validate console bus log file format and telegram checksums.
 
@@ -137,9 +143,9 @@ def validate_log_file(log_file_path: str) -> None:
     \b
         xp file validate conbus.log
     """
-    from ...services.log_file_service import LogFileService
+    from xp.services.log_file_service import LogFileService
 
-    service = LogFileService()
+    service = ctx.obj.get("container").get_container().resolve(LogFileService)
     OutputFormatter(True)
 
     try:
