@@ -1,7 +1,8 @@
-import click
 from typing import Any, Optional
 
-from xp.models.datapoint_type import DataPointType
+import click
+
+from xp.models.telegram.datapoint_type import DataPointType
 
 
 # noinspection DuplicatedCode
