@@ -1,8 +1,10 @@
 """Error handling utilities for CLI commands."""
 
+from typing import Any, Dict, Optional
+
 import click
-from typing import Dict, Any, Optional
-from .formatters import OutputFormatter
+
+from xp.cli.utils.formatters import OutputFormatter
 
 
 class CLIErrorHandler:
