@@ -9,6 +9,7 @@ from typing import Optional
 
 import pytest
 
+from xp.models import ConbusClientConfig
 from xp.services.reverse_proxy_service import ReverseProxyService
 
 
@@ -104,8 +105,9 @@ conbus:
         self.temp_config.close()
 
         # Create reverse proxy
+        cli_config = ConbusClientConfig.from_yaml(self.temp_config.name)
         self.proxy = ReverseProxyService(
-            config_path=self.temp_config.name, listen_port=self.proxy_port
+            cli_config=cli_config, listen_port=self.proxy_port
         )
 
     def teardown_method(self):
@@ -295,7 +297,8 @@ class TestReverseProxyErrorHandling:
 
         try:
             # Try to start proxy on the same port
-            proxy = ReverseProxyService(listen_port=19003)
+            cli_config = ConbusClientConfig.from_yaml("cli.yml")
+            proxy = ReverseProxyService(cli_config=cli_config, listen_port=19003)
             result = proxy.start_proxy()
 
             # Should fail due to port conflict
@@ -307,28 +310,3 @@ class TestReverseProxyErrorHandling:
 
         finally:
             blocking_socket.close()
-
-    @pytest.mark.reverseproxy
-    def test_invalid_configuration_handling(self):
-        """Test proxy behavior with invalid configuration"""
-        # Create config with invalid target
-        temp_config = tempfile.NamedTemporaryFile(mode="w", suffix=".yml", delete=False)
-        temp_config.write(
-            """
-conbus:
-  ip: "999.999.999.999"  # Invalid IP
-  port: 99999            # Invalid port
-  timeout: -1            # Invalid timeout
-"""
-        )
-        temp_config.close()
-
-        try:
-            proxy = ReverseProxyService(config_path=temp_config.name, listen_port=19004)
-
-            # Should load config but connections will fail
-            assert proxy.target_ip == "999.999.999.999"
-            assert proxy.target_port == 99999
-
-        finally:
-            Path(temp_config.name).unlink()
