@@ -1,62 +1,83 @@
 from datetime import datetime
-from unittest.mock import Mock, patch
+from unittest.mock import Mock
 
 import pytest
 
-from xp.services.conbus_linknumber_service import ConbusLinknumberService
-from xp.services.telegram_link_number_service import LinkNumberError
-from xp.models.conbus_linknumber import ConbusLinknumberResponse
-from xp.models.reply_telegram import ReplyTelegram
+from xp.models.conbus.conbus_linknumber import ConbusLinknumberResponse
+from xp.models.telegram.reply_telegram import ReplyTelegram
+from xp.services.conbus.conbus_linknumber_service import ConbusLinknumberService
+from xp.services.telegram.telegram_link_number_service import LinkNumberError
 
 
 class TestConbusLinknumberService:
     """Test cases for ConbusLinknumberService"""
 
     @pytest.fixture
-    def mock_config_file(self, tmp_path):
-        """Create a temporary config file for testing"""
-        config_file = tmp_path / "test_cli.yml"
-        config_content = """
-conbus:
-  ip: 10.0.0.1
-  port: 8080
-  timeout: 15
-"""
-        config_file.write_text(config_content)
-        return str(config_file)
+    def mock_conbus_service(self):
+        """Create mock ConbusService"""
+        return Mock()
 
     @pytest.fixture
-    def service(self, mock_config_file):
-        """Create service instance with test config"""
-        return ConbusLinknumberService(config_path=mock_config_file)
+    def mock_datapoint_service(self):
+        """Create mock ConbusDatapointService"""
+        return Mock()
 
-    def test_service_initialization(self, mock_config_file):
+    @pytest.fixture
+    def mock_link_number_service(self):
+        """Create mock LinkNumberService"""
+        return Mock()
+
+    @pytest.fixture
+    def mock_telegram_service(self):
+        """Create mock TelegramService"""
+        return Mock()
+
+    @pytest.fixture
+    def service(
+        self,
+        mock_conbus_service,
+        mock_datapoint_service,
+        mock_link_number_service,
+        mock_telegram_service,
+    ):
+        """Create service instance with mocked dependencies"""
+        return ConbusLinknumberService(
+            conbus_service=mock_conbus_service,
+            datapoint_service=mock_datapoint_service,
+            link_number_service=mock_link_number_service,
+            telegram_service=mock_telegram_service,
+        )
+
+    def test_service_initialization(
+        self,
+        mock_conbus_service,
+        mock_datapoint_service,
+        mock_link_number_service,
+        mock_telegram_service,
+    ):
         """Test service initialization"""
-        service = ConbusLinknumberService(config_path=mock_config_file)
+        service = ConbusLinknumberService(
+            conbus_service=mock_conbus_service,
+            datapoint_service=mock_datapoint_service,
+            link_number_service=mock_link_number_service,
+            telegram_service=mock_telegram_service,
+        )
 
         assert service.conbus_service is not None
         assert service.datapoint_service is not None
         assert service.link_number_service is not None
         assert service.telegram_service is not None
 
-    @patch("xp.services.conbus_linknumber_service.ConbusService")
-    @patch("xp.services.conbus_linknumber_service.LinkNumberService")
-    @patch("xp.services.conbus_linknumber_service.TelegramService")
-    def test_set_linknumber_success_ack(
-        self,
-        mock_telegram_service_class,
-        mock_link_service_class,
-        mock_conbus_service_class,
-    ):
+    def test_set_linknumber_success_ack(self):
         """Test successful link number setting with ACK response"""
         # Setup mocks
         mock_conbus_service = Mock()
         mock_conbus_service.__enter__ = Mock(return_value=mock_conbus_service)
         mock_conbus_service.__exit__ = Mock(return_value=None)
-        mock_conbus_service_class.return_value = mock_conbus_service
+
+        mock_datapoint_service = Mock()
 
         mock_link_service = Mock()
-        mock_link_service_class.return_value = mock_link_service
         mock_link_service.generate_set_link_number_telegram.return_value = (
             "<S0123450001F04D0425FO>"
         )
@@ -64,7 +85,6 @@ conbus:
         mock_link_service.is_nak_response.return_value = False
 
         mock_telegram_service = Mock()
-        mock_telegram_service_class.return_value = mock_telegram_service
 
         # Mock ReplyTelegram
         mock_reply = Mock(spec=ReplyTelegram)
@@ -78,8 +98,14 @@ conbus:
         mock_response.timestamp = datetime(2025, 9, 26, 13, 11, 25, 820383)
         mock_conbus_service.send_raw_telegram.return_value = mock_response
 
+        # Create service with mocked dependencies
         # Test
-        result = ConbusLinknumberService().set_linknumber("0123450001", 25)
+        result = ConbusLinknumberService(
+            conbus_service=mock_conbus_service,
+            datapoint_service=mock_datapoint_service,
+            link_number_service=mock_link_service,
+            telegram_service=mock_telegram_service,
+        ).set_linknumber("0123450001", 25)
 
         # Assertions
         assert isinstance(result, ConbusLinknumberResponse)
@@ -90,24 +116,16 @@ conbus:
         assert result.received_telegrams == ["<R0123450001F04D0400FH>"]
         assert result.error is None
 
-    @patch("xp.services.conbus_linknumber_service.ConbusService")
-    @patch("xp.services.conbus_linknumber_service.LinkNumberService")
-    @patch("xp.services.conbus_linknumber_service.TelegramService")
-    def test_set_linknumber_success_nak(
-        self,
-        mock_telegram_service_class,
-        mock_link_service_class,
-        mock_conbus_service_class,
-    ):
+    def test_set_linknumber_success_nak(self):
         """Test link number setting with NAK response"""
         # Setup mocks
         mock_conbus_service = Mock()
         mock_conbus_service.__enter__ = Mock(return_value=mock_conbus_service)
         mock_conbus_service.__exit__ = Mock(return_value=None)
-        mock_conbus_service_class.return_value = mock_conbus_service
+
+        mock_datapoint_service = Mock()
 
         mock_link_service = Mock()
-        mock_link_service_class.return_value = mock_link_service
         mock_link_service.generate_set_link_number_telegram.return_value = (
             "<S0123450001F04D0425FO>"
         )
@@ -115,7 +133,6 @@ conbus:
         mock_link_service.is_nak_response.return_value = True
 
         mock_telegram_service = Mock()
-        mock_telegram_service_class.return_value = mock_telegram_service
 
         # Mock ReplyTelegram
         mock_reply = Mock(spec=ReplyTelegram)
@@ -129,8 +146,14 @@ conbus:
         mock_response.timestamp = datetime(2025, 9, 26, 13, 11, 25, 820383)
         mock_conbus_service.send_raw_telegram.return_value = mock_response
 
+        # Create service with mocked dependencies
         # Test
-        result = ConbusLinknumberService().set_linknumber("0123450001", 25)
+        result = ConbusLinknumberService(
+            conbus_service=mock_conbus_service,
+            datapoint_service=mock_datapoint_service,
+            link_number_service=mock_link_service,
+            telegram_service=mock_telegram_service,
+        ).set_linknumber("0123450001", 25)
 
         # Assertions
         assert isinstance(result, ConbusLinknumberResponse)
@@ -138,24 +161,22 @@ conbus:
         assert result.result == "NAK"
         assert result.serial_number == "0123450001"
 
-    @patch("xp.services.conbus_linknumber_service.ConbusService")
-    @patch("xp.services.conbus_linknumber_service.LinkNumberService")
-    def test_set_linknumber_connection_failure(
-        self, mock_link_service_class, mock_conbus_service_class
-    ):
+    def test_set_linknumber_connection_failure(self):
         """Test link number setting with connection failure"""
         # Setup mocks
         mock_conbus_service = Mock()
         mock_conbus_service.__enter__ = Mock(return_value=mock_conbus_service)
         mock_conbus_service.__exit__ = Mock(return_value=None)
-        mock_conbus_service_class.return_value = mock_conbus_service
+
+        mock_datapoint_service = Mock()
 
         mock_link_service = Mock()
-        mock_link_service_class.return_value = mock_link_service
         mock_link_service.generate_set_link_number_telegram.return_value = (
             "<S0123450001F04D0425FO>"
         )
 
+        mock_telegram_service = Mock()
+
         # Mock ConbusService response for connection failure
         mock_response = Mock()
         mock_response.success = False
@@ -164,8 +185,14 @@ conbus:
         mock_response.timestamp = datetime.now()
         mock_conbus_service.send_raw_telegram.return_value = mock_response
 
+        # Create service with mocked dependencies
         # Test
-        result = ConbusLinknumberService().set_linknumber("0123450001", 25)
+        result = ConbusLinknumberService(
+            conbus_service=mock_conbus_service,
+            datapoint_service=mock_datapoint_service,
+            link_number_service=mock_link_service,
+            telegram_service=mock_telegram_service,
+        ).set_linknumber("0123450001", 25)
 
         # Assertions
         assert isinstance(result, ConbusLinknumberResponse)
@@ -173,18 +200,28 @@ conbus:
         assert result.result == "NAK"
         assert result.error == "Connection timeout"
 
-    @patch("xp.services.conbus_linknumber_service.LinkNumberService")
-    def test_set_linknumber_invalid_parameters(self, mock_link_service_class):
+    def test_set_linknumber_invalid_parameters(self):
         """Test link number setting with invalid parameters"""
         # Setup mocks
+        mock_conbus_service = Mock()
+
+        mock_datapoint_service = Mock()
+
         mock_link_service = Mock()
-        mock_link_service_class.return_value = mock_link_service
         mock_link_service.generate_set_link_number_telegram.side_effect = (
             LinkNumberError("Invalid link number")
         )
 
+        mock_telegram_service = Mock()
+
+        # Create service with mocked dependencies
         # Test
-        result = ConbusLinknumberService().set_linknumber("invalid", 101)
+        result = ConbusLinknumberService(
+            conbus_service=mock_conbus_service,
+            datapoint_service=mock_datapoint_service,
+            link_number_service=mock_link_service,
+            telegram_service=mock_telegram_service,
+        ).set_linknumber("invalid", 101)
 
         # Assertions
         assert isinstance(result, ConbusLinknumberResponse)
@@ -197,26 +234,22 @@ conbus:
         with service as s:
             assert s is service
 
-    @patch("xp.services.conbus_linknumber_service.ConbusService")
-    @patch("xp.services.conbus_linknumber_service.LinkNumberService")
-    def test_set_linknumber_no_received_telegrams(
-        self,
-        mock_link_service_class,
-        mock_conbus_service_class,
-    ):
+    def test_set_linknumber_no_received_telegrams(self):
         """Test link number setting with no received telegrams"""
         # Setup mocks
         mock_conbus_service = Mock()
         mock_conbus_service.__enter__ = Mock(return_value=mock_conbus_service)
         mock_conbus_service.__exit__ = Mock(return_value=None)
-        mock_conbus_service_class.return_value = mock_conbus_service
+
+        mock_datapoint_service = Mock()
 
         mock_link_service = Mock()
-        mock_link_service_class.return_value = mock_link_service
         mock_link_service.generate_set_link_number_telegram.return_value = (
             "<S0123450001F04D0425FO>"
         )
 
+        mock_telegram_service = Mock()
+
         # Mock ConbusService response with no received telegrams
         mock_response = Mock()
         mock_response.success = True
@@ -225,20 +258,26 @@ conbus:
         mock_response.timestamp = datetime.now()
         mock_conbus_service.send_raw_telegram.return_value = mock_response
 
+        # Create service with mocked dependencies
         # Test
-        result = ConbusLinknumberService().set_linknumber("0123450001", 25)
+        result = ConbusLinknumberService(
+            conbus_service=mock_conbus_service,
+            datapoint_service=mock_datapoint_service,
+            link_number_service=mock_link_service,
+            telegram_service=mock_telegram_service,
+        ).set_linknumber("0123450001", 25)
 
         # Assertions
         assert isinstance(result, ConbusLinknumberResponse)
         assert result.success is False  # Should be False because no ACK received
         assert result.result == "NAK"
 
-    @patch("xp.services.conbus_linknumber_service.ConbusDatapointService")
-    def test_get_linknumber_success(self, mock_datapoint_service_class):
+    def test_get_linknumber_success(self):
         """Test successful link number retrieval"""
-        # Setup mock datapoint service
+        # Setup mocks
+        mock_conbus_service = Mock()
+
         mock_datapoint_service = Mock()
-        mock_datapoint_service_class.return_value = mock_datapoint_service
 
         # Mock successful datapoint response
         mock_datapoint_response = Mock()
@@ -250,8 +289,18 @@ conbus:
         mock_datapoint_response.timestamp = datetime.now()
         mock_datapoint_service.query_datapoint.return_value = mock_datapoint_response
 
+        mock_link_service = Mock()
+
+        mock_telegram_service = Mock()
+
+        # Create service with mocked dependencies
         # Test
-        result = ConbusLinknumberService().get_linknumber("0123450001")
+        result = ConbusLinknumberService(
+            conbus_service=mock_conbus_service,
+            datapoint_service=mock_datapoint_service,
+            link_number_service=mock_link_service,
+            telegram_service=mock_telegram_service,
+        ).get_linknumber("0123450001")
 
         # Assertions
         assert isinstance(result, ConbusLinknumberResponse)
@@ -262,18 +311,18 @@ conbus:
         assert result.sent_telegram == "<S0123450001F03D04FG>"
 
         # Verify datapoint service was called correctly
-        from xp.models.datapoint_type import DataPointType
+        from xp.models.telegram.datapoint_type import DataPointType
 
         mock_datapoint_service.query_datapoint.assert_called_once_with(
             DataPointType.LINK_NUMBER, "0123450001"
         )
 
-    @patch("xp.services.conbus_linknumber_service.ConbusDatapointService")
-    def test_get_linknumber_query_failed(self, mock_datapoint_service_class):
+    def test_get_linknumber_query_failed(self):
         """Test link number retrieval when datapoint query fails"""
-        # Setup mock datapoint service
+        # Setup mocks
+        mock_conbus_service = Mock()
+
         mock_datapoint_service = Mock()
-        mock_datapoint_service_class.return_value = mock_datapoint_service
 
         # Mock failed datapoint response
         mock_datapoint_response = Mock()
@@ -285,8 +334,18 @@ conbus:
         mock_datapoint_response.timestamp = datetime.now()
         mock_datapoint_service.query_datapoint.return_value = mock_datapoint_response
 
+        mock_link_service = Mock()
+
+        mock_telegram_service = Mock()
+
+        # Create service with mocked dependencies
         # Test
-        result = ConbusLinknumberService().get_linknumber("0123450001")
+        result = ConbusLinknumberService(
+            conbus_service=mock_conbus_service,
+            datapoint_service=mock_datapoint_service,
+            link_number_service=mock_link_service,
+            telegram_service=mock_telegram_service,
+        ).get_linknumber("0123450001")
 
         # Assertions
         assert isinstance(result, ConbusLinknumberResponse)
@@ -296,12 +355,12 @@ conbus:
         assert result.link_number is None
         assert result.error == "Connection timeout"
 
-    @patch("xp.services.conbus_linknumber_service.ConbusDatapointService")
-    def test_get_linknumber_parse_error(self, mock_datapoint_service_class):
+    def test_get_linknumber_parse_error(self):
         """Test link number retrieval when parsing fails"""
-        # Setup mock datapoint service
+        # Setup mocks
+        mock_conbus_service = Mock()
+
         mock_datapoint_service = Mock()
-        mock_datapoint_service_class.return_value = mock_datapoint_service
 
         # Mock successful datapoint response with invalid data
         mock_datapoint_response = Mock()
@@ -313,8 +372,18 @@ conbus:
         mock_datapoint_response.timestamp = datetime.now()
         mock_datapoint_service.query_datapoint.return_value = mock_datapoint_response
 
+        mock_link_service = Mock()
+
+        mock_telegram_service = Mock()
+
+        # Create service with mocked dependencies
         # Test
-        result = ConbusLinknumberService().get_linknumber("0123450001")
+        result = ConbusLinknumberService(
+            conbus_service=mock_conbus_service,
+            datapoint_service=mock_datapoint_service,
+            link_number_service=mock_link_service,
+            telegram_service=mock_telegram_service,
+        ).get_linknumber("0123450001")
 
         # Assertions
         assert isinstance(result, ConbusLinknumberResponse)
@@ -326,16 +395,27 @@ conbus:
             result.error is not None and "Failed to parse link number" in result.error
         )
 
-    @patch("xp.services.conbus_linknumber_service.ConbusDatapointService")
-    def test_get_linknumber_exception(self, mock_datapoint_service_class):
+    def test_get_linknumber_exception(self):
         """Test link number retrieval when exception occurs"""
+        # Setup mocks
+        mock_conbus_service = Mock()
+
         # Setup mock datapoint service that raises exception
         mock_datapoint_service = Mock()
-        mock_datapoint_service_class.return_value = mock_datapoint_service
         mock_datapoint_service.query_datapoint.side_effect = Exception("Service error")
 
+        mock_link_service = Mock()
+
+        mock_telegram_service = Mock()
+
+        # Create service with mocked dependencies
         # Test
-        result = ConbusLinknumberService().get_linknumber("0123450001")
+        result = ConbusLinknumberService(
+            conbus_service=mock_conbus_service,
+            datapoint_service=mock_datapoint_service,
+            link_number_service=mock_link_service,
+            telegram_service=mock_telegram_service,
+        ).get_linknumber("0123450001")
 
         # Assertions
         assert isinstance(result, ConbusLinknumberResponse)
