@@ -1,9 +1,10 @@
 import pytest
+
+from xp.models.telegram.module_type import ModuleType
 from xp.services.module_type_service import (
-    ModuleTypeService,
     ModuleTypeNotFoundError,
+    ModuleTypeService,
 )
-from xp.models.module_type import ModuleType
 
 
 class TestModuleTypeService:
