@@ -1,7 +1,12 @@
 import pytest
-from xp.services.telegram_output_service import TelegramOutputService, XPOutputError
-from xp.models.output_telegram import OutputTelegram
-from xp.models.system_function import SystemFunction
+
+from xp.models.telegram.output_telegram import OutputTelegram
+from xp.models.telegram.system_function import SystemFunction
+from xp.services.telegram.telegram_output_service import (
+    TelegramOutputService,
+    XPOutputError,
+)
+from xp.services.telegram.telegram_service import TelegramService
 
 
 class TestTelegramInputServiceAckNak:
@@ -9,7 +14,7 @@ class TestTelegramInputServiceAckNak:
 
     def setup_method(self):
         """Setup test fixtures"""
-        self.service = TelegramOutputService()
+        self.service = TelegramOutputService(telegram_service=TelegramService())
 
     def test_parse_valid_ack_telegram(self):
         """Test parsing a valid ACK telegram"""
